All of lore.kernel.org
 help / color / mirror / Atom feed
* [PATCH] xmm7modem: CPIN handling after sending puk
@ 2019-12-19 12:57 Antara Borwankar
  2019-12-20 18:50 ` Denis Kenzior
  0 siblings, 1 reply; 2+ messages in thread
From: Antara Borwankar @ 2019-12-19 12:57 UTC (permalink / raw)
  To: ofono

[-- Attachment #1: Type: text/plain, Size: 1168 bytes --]

On XMM modems SIM is busy after PUK is entered. CME ERROR: 14
is received for AT+CPIN? query. Therefore polling for CPIN: READY
state.
---
 drivers/atmodem/sim.c | 5 +++--
 1 file changed, 3 insertions(+), 2 deletions(-)

diff --git a/drivers/atmodem/sim.c b/drivers/atmodem/sim.c
index e750a13..3ed5aa0 100644
--- a/drivers/atmodem/sim.c
+++ b/drivers/atmodem/sim.c
@@ -1354,13 +1354,14 @@ static void at_pin_send_cb(gboolean ok, GAtResult *result,
 	case OFONO_VENDOR_HUAWEI:
 	case OFONO_VENDOR_SIMCOM:
 	case OFONO_VENDOR_SIERRA:
+	case OFONO_VENDOR_XMM:
 		/*
 		 * On ZTE modems, after pin is entered, SIM state is checked
 		 * by polling CPIN as their modem doesn't provide unsolicited
 		 * notification of SIM readiness.
 		 *
 		 * On SIMCOM modems, SIM is busy after pin is entered (we
 		 * got a "+CME ERROR: 14" for the "AT+CPIN?" request) and
 		 * ofono don't catch the "+CPIN: READY" message sent by the
 		 * modem when SIM is ready. So, use extra CPIN to check the
 		 * state.
@@ -1354,13 +1354,14 @@ static void at_pin_send_cb(gboolean ok, GAtResult *result,
 		 * notification of SIM readiness.
 		 *
-		 * On SIMCOM modems, SIM is busy after pin is entered (we
-		 * got a "+CME ERROR: 14" for the "AT+CPIN?" request) and
+		 * On SIMCOM and XMM modems, SIM is busy after pin is entered
+		 * (we got a "+CME ERROR: 14" for the "AT+CPIN?" request) and
 		 * ofono don't catch the "+CPIN: READY" message sent by the
 		 * modem when SIM is ready. So, use extra CPIN to check the
-- 
1.9.1

^ permalink raw reply related	[flat|nested] 2+ messages in thread

* Re: [PATCH] xmm7modem: CPIN handling after sending puk
  2019-12-19 12:57 [PATCH] xmm7modem: CPIN handling after sending puk Antara Borwankar
@ 2019-12-20 18:50 ` Denis Kenzior
  0 siblings, 0 replies; 2+ messages in thread
From: Denis Kenzior @ 2019-12-20 18:50 UTC (permalink / raw)
  To: ofono

[-- Attachment #1: Type: text/plain, Size: 1568 bytes --]

Hi Antara,

On 12/19/19 6:57 AM, Antara Borwankar wrote:
> On XMM modems SIM is busy after PUK is entered. CME ERROR: 14
> is received for AT+CPIN? query. Therefore polling for CPIN: READY
> state.
> ---
>   drivers/atmodem/sim.c | 5 +++--
>   1 file changed, 3 insertions(+), 2 deletions(-)
> 
> diff --git a/drivers/atmodem/sim.c b/drivers/atmodem/sim.c
> index e750a13..3ed5aa0 100644
> --- a/drivers/atmodem/sim.c
> +++ b/drivers/atmodem/sim.c
> @@ -1354,13 +1354,14 @@ static void at_pin_send_cb(gboolean ok, GAtResult *result,
>   	case OFONO_VENDOR_HUAWEI:
>   	case OFONO_VENDOR_SIMCOM:
>   	case OFONO_VENDOR_SIERRA:
> +	case OFONO_VENDOR_XMM:
>   		/*
>   		 * On ZTE modems, after pin is entered, SIM state is checked
>   		 * by polling CPIN as their modem doesn't provide unsolicited
>   		 * notification of SIM readiness.
>   		 *
> -		 * On SIMCOM modems, SIM is busy after pin is entered (we
> -		 * got a "+CME ERROR: 14" for the "AT+CPIN?" request) and
> +		 * On SIMCOM and XMM modems, SIM is busy after pin is entered
> +		 * (we got a "+CME ERROR: 14" for the "AT+CPIN?" request) and
>   		 * ofono don't catch the "+CPIN: READY" message sent by the
>   		 * modem when SIM is ready. So, use extra CPIN to check the
>   		 * state.
> 

Shouldn't this be already taken care of by setting wait_initialized 
inside src/sim.c sim_enter_pin_cb()?  This particular logic is a work 
around for modems that do not have a separate notification that can be 
used to send ofono_sim_initialized_notify.

Regards,
-Denis

^ permalink raw reply	[flat|nested] 2+ messages in thread

end of thread, other threads:[~2019-12-20 18:50 UTC | newest]

Thread overview: 2+ messages (download: mbox.gz / follow: Atom feed)
-- links below jump to the message on this page --
2019-12-19 12:57 [PATCH] xmm7modem: CPIN handling after sending puk Antara Borwankar
2019-12-20 18:50 ` Denis Kenzior

This is an external index of several public inboxes,
see mirroring instructions on how to clone and mirror
all data and code used by this external index.